% image reconstruction from orthogonal moments

n1 = 20;	% number of polynomials/moments
n2 = n1;	% number of polynomials/moments
r = 2^9; 	% size of image

% orthogonal polynomials type: uncomment selected family
type = 'Legendre';	% Legendre polynomials
%type = 'DChebyshev';	% discrete Chebyshev polynomials
%type = 'Cheb2';	% second kind Chebyshev polynomials

if strcmp(type(1:5),'DCheb')
	disp('Image reconstruction by discrete Chebyshev moments.')
elseif strcmp(type(1:5),'Legen')
	disp('Image reconstruction by Legendre moments.')
elseif strcmp(type(1:5),'Cheb2')
	disp('Image reconstruction by second kind Chebyshev moments.')
else
	error('unknown moments.')
end

% create test image
f = @(x,y) 0.5*exp(x).*sin(pi*x).*sin(pi*y);
A = 2;
x = linspace(-A/2,A/2,r);
[X Y] = meshgrid(x,x);
F = f(X,Y);
F = F-min(F(:));
F = F/max(F(:));
[m1 m2] = size(F);
if ~(2*round(m1/2)-m1), m1 = m1-1; end	% for Simpson
if ~(2*round(m2/2)-m2), m2 = m2-1; end	% for Simpson
F = F(1:m1,1:m2);
figure(1)
imshow(F)
title('test image')

% sampling on both axes
if strcmp(type(1:5),'DCheb')
	x = [0:m1-1]';
	y = [0:m2-1]';
else
	x = linspace(-1,1,m1)';
	y = linspace(-1,1,m2)';
end

% recursion coefficients computation and polynomial evaluation
[alfa1 beta1] = opcoef(type,n1,m1);	% recursion coefficients
[alfa2 beta2] = opcoef(type,n2,m2);	% recursion coefficients
P1 = opevmat(alfa1,beta1,x);		% values of polynomials on x
P2 = opevmat(alfa2,beta2,y);		% values of polynomials on y

% check moments
% computation of orthogonal moments
ord = max([n1,n2]);
if strcmp(type(1:5),'DCheb')
	M = dchebmoms(F,ord);
elseif strcmp(type(1:5),'Legen')
	M = legmoms(F,ord);
elseif strcmp(type(1:5),'Cheb2')
	M = cheb2moms(F,ord);
else
	error('unknown moments.')
end

figure(2)
pcolor(log10(abs(M)))
colormap hot
axis image
axis ij
colorbar
title('log10 of moments')

% image reconstruction by continuous moments
X = P1*M*P2';
errc = norm(F(:)-X(:),inf);
figure(3)
imshow(mat2gray(X),[0 1])
title('image reconstruction from moments')
xlabel(sprintf('error=%.2e',errc))

